print("import: 'xlwings'")
import xlwings

print("import: 'xlwings.conversion'")
import xlwings.conversion

print("import: 'xlwings.ext'")
import xlwings.ext

print("import: 'xlwings.quickstart_fastapi'")
import xlwings.quickstart_fastapi

print("import: 'xlwings.rest'")
import xlwings.rest

